@@ -10,17 +10,18 @@ KW_OPEN_API = 'swagger'
 DOCUMENTATION_FILE = f'{KW_OPEN_API}{c.DOT}{KW_JSON}'
 
 def getDocumentationFolderPath(apiInstance):
-    globals = apiInstance.globals
-    return f'{globals.currentPath}{KW_API}{globals.OS_SEPARATOR}{KW_RESOURCE}{globals.OS_SEPARATOR}{KW_OPEN_API}{KW_UI}'
+    # globals = apiInstance.globals
+    # return f'{globals.currentPath}{KW_API}{globals.OS_SEPARATOR}{KW_RESOURCE}{globals.OS_SEPARATOR}{KW_OPEN_API}{KW_UI}'
+    return apiInstance.documentationFolderPath
 
 def getDocumentationFilePath(apiInstance):
-    globals = apiInstance.globals
-    return f'{getDocumentationFolderPath(apiInstance)}{globals.OS_SEPARATOR}{DOCUMENTATION_FILE}'
+    # globals = apiInstance.globals
+    # return f'{getDocumentationFolderPath(apiInstance)}{globals.OS_SEPARATOR}{DOCUMENTATION_FILE}'
+    return f'{apiInstance.documentationFolderPath}{DOCUMENTATION_FILE}'
 
 def loadDocumentationAsString(apiInstance):
     globals = apiInstance.globals
-    documentationFilePath = getDocumentationFilePath(apiInstance)
-    with open(documentationFilePath, globals.READ, encoding=globals.ENCODING) as documentationFile :
+    with open(getDocumentationFilePath(apiInstance), globals.READ, encoding=globals.ENCODING) as documentationFile :
         documentationAsString = c.NOTHING.join(documentationFile.readlines())
     return documentationAsString
 
@@ -31,6 +32,5 @@ def loadDocumentation(apiInstance):
 def overrideDocumentation(apiInstance):
     globals = apiInstance.globals
     documentationAsString = StringHelper.stringfyThisDictionary(apiInstance.documentation)
-    documentationFilePath = getDocumentationFilePath(apiInstance)
-    with open(documentationFilePath, globals.OVERRIDE, encoding=globals.ENCODING) as documentationFile :
+    with open(getDocumentationFilePath(apiInstance), globals.OVERRIDE, encoding=globals.ENCODING) as documentationFile :
         documentationFile.write(documentationAsString)
